==> bkup_15_7_24.zip: src/app/Http/Controllers/Auth/RegisteredUserController.php <==
<?php

namespace App\Http\Controllers\Auth;

use App\Enums\Status;
use App\Http\Controllers\Controller;
use App\Jobs\SendEmailVerificationJob;
use App\Models\User;
use App\Notifications\UserRegisteredNotification;
use App\Providers\RouteServiceProvider;
use App\Services\Payment\WalletService;
use App\Services\SettingService;
use App\Services\UserService;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Illuminate\Validation\Rules;
use Illuminate\Validation\ValidationException;
use Illuminate\View\View;
use Lunaweb\RecaptchaV3\Facades\RecaptchaV3;

class RegisteredUserController extends Controller
{
    public function __construct(
        protected WalletService $walletService,
        protected UserService $userService,
    )
    {

    }
    /**
     * Display the registration view.
     */
    public function create(): View
    {
        $setTitle = 'Register';
        $referral = $this->userService->getReferral();

        $setting = SettingService::getSetting();
        if (getArrayValue($setting?->system_configuration, 'registration_status.value') != Status::ACTIVE->value) {
            abort(404);
        }

        return view('auth.register', compact('referral', 'setTitle'));
    }
    
    

    /**
     * Handle an incoming registration request.
     *
     * @throws ValidationException
     */
     
     
     
     public function createfranchisee(): View
    {
        $setTitle = 'Register As Franchisee';
        $referral = $this->userService->getReferral();

        $setting = SettingService::getSetting();
        if (getArrayValue($setting?->system_configuration, 'registration_status.value') != Status::ACTIVE->value) {
            abort(404);
        }

        return view('auth.register-as-a-franchisee', compact('referral', 'setTitle'));
    }
     
     
     
    public function store(Request $request): RedirectResponse
    {
        $setting = SettingService::getSetting();

        if (getArrayValue($setting?->system_configuration, 'registration_status.value') != Status::ACTIVE->value) {
            abort(404);
        }

        if (getArrayValue($setting?->recaptcha_setting, 'registration') == Status::ACTIVE->value
            && RecaptchaV3::verify($request->input('g-recaptcha-response')) <= 0.3) {
            return back()->with('notify', [['error', 'Captcha verification failed']]);
        }

        $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'lowercase', 'email', 'max:255', 'unique:' . User::class],
            'password' => ['required', 'confirmed', Rules\Password::defaults()],
        ]);

        $referral = $this->userService->getReferral();
        $get_franchisee_id = $this->userService->getFranchisee($referral?->id);
        $user = User::create([
            'uuid' => Str::uuid(),
            'first_name' => $request->input('name'),
            'email' => $request->input('email'),
            'referral_by' => $referral?->id,
            'password' => Hash::make($request->input('password')),
        ]);
		User::where('id', $user->id)->update([
            'franchisee_id' => $get_franchisee_id,		
		]);

        if (getArrayValue($setting->system_configuration, 'email_verification.value') == Status::ACTIVE->value){
            SendEmailVerificationJob::dispatch($user);
        }else{
            $user->email_verified_at = now();
            $user->save();
        }

        $this->walletService->save($this->walletService->prepParams((int) $user->id));
        $user->notify(new UserRegisteredNotification());

        Auth::login($user);
        return redirect(RouteServiceProvider::HOME);
    }
    
    
    public function storefranchisee(Request $request): RedirectResponse
{
    $setting = SettingService::getSetting();

    if (getArrayValue($setting?->system_configuration, 'registration_status.value') != Status::ACTIVE->value) {
        abort(404);
    }

    if (getArrayValue($setting?->recaptcha_setting, 'registration') == Status::ACTIVE->value
        && RecaptchaV3::verify($request->input('g-recaptcha-response')) <= 0.3) {
        return back()->with('notify', [['error', 'Captcha verification failed']]);
    }

    $request->validate([
        'name' => ['required', 'string', 'max:255'],
        'email' => ['required', 'string', 'lowercase', 'email', 'max:255', 'unique:' . User::class],
        'password' => ['required', 'confirmed', Rules\Password::defaults()],
    ]);

    $user = User::create([
        'uuid' => Str::uuid(),
        'first_name' => $request->input('name'),
        'email' => $request->input('email'),
        'password' => Hash::make($request->input('password')),
         'is_franchisee' => 1, // Updted as Franchisee
        
    ]);

    if (getArrayValue($setting->system_configuration, 'email_verification.value') == Status::ACTIVE->value) {
        SendEmailVerificationJob::dispatch($user);
    } else {
        $user->email_verified_at = now();
        $user->save();
    }

    $this->walletService->save($this->walletService->prepParams((int) $user->id));
    $user->notify(new UserRegisteredNotification());

    Auth::login($user);
    return redirect(RouteServiceProvider::HOME);
}

}

==> bkup_17_7.zip: src/app/Http/Controllers/Auth/RegisteredUserController.php <==
<?php

namespace App\Http\Controllers\Auth;

use App\Enums\Status;
use App\Http\Controllers\Controller;
use App\Jobs\SendEmailVerificationJob;
use App\Models\User;
use App\Notifications\UserRegisteredNotification;
use App\Providers\RouteServiceProvider;
use App\Services\Payment\WalletService;
use App\Services\SettingService;
use App\Services\UserService;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Illuminate\Validation\Rules;
use Illuminate\Validation\ValidationException;
use Illuminate\View\View;
use Lunaweb\RecaptchaV3\Facades\RecaptchaV3;

class RegisteredUserController extends Controller
{
    public function __construct(
        protected WalletService $walletService,
        protected UserService $userService,
    )
    {

    }
    /**
     * Display the registration view.
     */
    public function create(): View
    {
        $setTitle = 'Register';
        $referral = $this->userService->getReferral();

        $setting = SettingService::getSetting();
        if (getArrayValue($setting?->system_configuration, 'registration_status.value') != Status::ACTIVE->value) {
            abort(404);
        }

        return view('auth.register', compact('referral', 'setTitle'));
    }
    
    

    /**
     * Handle an incoming registration request.
     *
     * @throws ValidationException
     */
     
     
     
     public function createfranchisee(): View
    {
        $setTitle = 'Register As Franchisee';
        $referral = $this->userService->getReferral();

        $setting = SettingService::getSetting();
        if (getArrayValue($setting?->system_configuration, 'registration_status.value') != Status::ACTIVE->value) {
            abort(404);
        }

        return view('auth.register-as-a-franchisee', compact('referral', 'setTitle'));
    }
     
     
     
public function store(Request $request): RedirectResponse
{
    $setting = SettingService::getSetting();

    if (getArrayValue($setting?->system_configuration, 'registration_status.value') != Status::ACTIVE->value) {
        abort(404);
    }

    if (getArrayValue($setting?->recaptcha_setting, 'registration') == Status::ACTIVE->value
        && RecaptchaV3::verify($request->input('g-recaptcha-response')) <= 0.3) {
        return back()->with('notify', [['error', 'Captcha verification failed']]);
    }

    $request->validate([
        'name' => ['required', 'string', 'max:255'],
        'username' => ['required', 'string', 'max:255', 'unique:' . User::class],
        'email' => ['required', 'string', 'lowercase', 'email', 'max:255', 'unique:' . User::class],
        'password' => ['required', 'confirmed', Rules\Password::defaults()],
    ]);

    $referral = $this->userService->getReferral();
    $get_franchisee_id = $this->userService->getFranchisee($referral?->id);
    $user = User::create([
        'uuid' => Str::uuid(),
        'first_name' => $request->input('name'),
        'username' => $request->input('username'),
        'email' => $request->input('email'),
        'referral_by' => $referral?->id,
        'password' => Hash::make($request->input('password')),
    ]);

    User::where('id', $user->id)->update([
        'franchisee_id' => $get_franchisee_id,
    ]);

    if (getArrayValue($setting->system_configuration, 'email_verification.value') == Status::ACTIVE->value) {
        SendEmailVerificationJob::dispatch($user);
    } else {
        $user->email_verified_at = now();
        $user->save();
    }

    $this->walletService->save($this->walletService->prepParams((int) $user->id));
    $user->notify(new UserRegisteredNotification());

    Auth::login($user);
    return redirect(RouteServiceProvider::HOME);
}

public function storefranchisee(Request $request): RedirectResponse
{
    $setting = SettingService::getSetting();

    if (getArrayValue($setting?->system_configuration, 'registration_status.value') != Status::ACTIVE->value) {
        abort(404);
    }

    if (getArrayValue($setting?->recaptcha_setting, 'registration') == Status::ACTIVE->value
        && RecaptchaV3::verify($request->input('g-recaptcha-response')) <= 0.3) {
        return back()->with('notify', [['error', 'Captcha verification failed']]);
    }

    $request->validate([
        'name' => ['required', 'string', 'max:255'],
        'username' => ['required', 'string', 'max:255', 'unique:' . User::class],
        'email' => ['required', 'string', 'lowercase', 'email', 'max:255', 'unique:' . User::class],
        'password' => ['required', 'confirmed', Rules\Password::defaults()],
    ]);

    $user = User::create([
        'uuid' => Str::uuid(),
        'first_name' => $request->input('name'),
        'username' => $request->input('username'),
        'email' => $request->input('email'),
        'password' => Hash::make($request->input('password')),
        'is_franchisee' => 1, // Updated as Franchisee
    ]);

    if (getArrayValue($setting->system_configuration, 'email_verification.value') == Status::ACTIVE->value) {
        SendEmailVerificationJob::dispatch($user);
    } else {
        $user->email_verified_at = now();
        $user->save();
    }

    $this->walletService->save($this->walletService->prepParams((int) $user->id));
    $user->notify(new UserRegisteredNotification());

    Auth::login($user);
    return redirect(RouteServiceProvider::HOME);
}

}
